;; 
;; qwiki-install - installation script for the quick wiki
;; 
;; Copyright (c) 2009-2018 Peter Bex and Ivan Raikov
;;
;;  Redistribution and use in source and binary forms, with or without
;;  modification, are permitted provided that the following conditions
;;  are met:
;; 
;;  - Redistributions of source code must retain the above copyright
;;  notice, this list of conditions and the following disclaimer.
;; 
;;  - Redistributions in binary form must reproduce the above
;;  copyright notice, this list of conditions and the following
;;  disclaimer in the documentation and/or other materials provided
;;  with the distribution.
;; 
;;  - Neither name of the copyright holders nor the names of its
;;  contributors may be used to endorse or promote products derived
;;  from this software without specific prior written permission.
;; 
;;  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND THE
;;  CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
;;  INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
;;  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
;;  DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDERS OR THE
;;  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
;;  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
;;  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
;;  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
;;  AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
;;  LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
;;  ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
;;  POSSIBILITY OF SUCH DAMAGE.

(module qwiki-install
  (qwiki-install! qwiki-pre-install-handlers)

(import scheme (chicken base) (chicken file) (chicken file posix)
        qwiki qwiki-svn srfi-13)

(define (traverse-file-tree base-path)
  (for-each
   (lambda (f)
     (let* ((path (append base-path (list f)))
            (string-path (string-join (cons (qwiki-source-path) path) "/")))
       (unless (symbolic-link? string-path)
         (if (directory? string-path)
             (traverse-file-tree path)
             (begin
               (print (string-join path "/"))
               (qwiki-update-file! path))))))
   (directory (string-join (cons (qwiki-source-path) base-path) "/"))))

(define qwiki-pre-install-handlers
  (make-parameter (list)))

(define (qwiki-install!)
  (checkout-sources! (qwiki-source-path))
  (for-each (lambda (thunk) (thunk)) (qwiki-pre-install-handlers))
  (traverse-file-tree '()))

) ; end module
